@@ -721,16 +721,6 @@ impl Default for CiRenderGatherCallbackArgsT {
     }
 }
 #[repr(C)]
-#[derive(Copy, Clone)]
-pub struct RenderGraphModuleO {
-    _unused: [u8; 0],
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct ShaderSystemContextO {
-    _unused: [u8; 0],
-}
-#[repr(C)]
 #[derive(Default, Copy, Clone)]
 pub struct CiShaderI {
     pub init: ::std::option::Option<
@@ -792,11 +782,6 @@ impl Default for CiShaderDataGatherCallbackArgsT {
     }
 }
 #[repr(C)]
-#[derive(Copy, Clone)]
-pub struct RendererBufferDescT {
-    _unused: [u8; 0],
-}
-#[repr(C)]
 pub struct CullingViewerT {
     pub frustum_planes: [Vec4T; 6usize],
     pub visibility_mask: u64,
@@ -1106,11 +1091,6 @@ pub struct RenderPipelineI {
     _unused: [u8; 0],
 }
 #[repr(C)]
-#[derive(Copy, Clone)]
-pub struct SimulateEntryI {
-    _unused: [u8; 0],
-}
-#[repr(C)]
 pub struct LightingEnvironmentSettingsT {
     pub enabled: bool,
     pub _padding_31: [::std::os::raw::c_char; 7usize],
@@ -1350,31 +1330,11 @@ pub struct TheTruthStripperI {
 }
 #[repr(C)]
 #[derive(Copy, Clone)]
-pub struct RenderGraphO {
-    _unused: [u8; 0],
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
 pub struct RenderPipelineUpdateFrameParametersT {
     _unused: [u8; 0],
 }
 #[repr(C)]
 #[derive(Copy, Clone)]
-pub struct RendererBackendI {
-    _unused: [u8; 0],
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct RendererImageDescT {
-    _unused: [u8; 0],
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
-pub struct RendererResourceBarrierT {
-    _unused: [u8; 0],
-}
-#[repr(C)]
-#[derive(Copy, Clone)]
 pub struct RenderdocToolbarArgsT {
     _unused: [u8; 0],
 }
@@ -1546,26 +1506,6 @@ pub struct AssetPreviewO {
 pub struct AssetSceneO {
     pub _address: u8,
 }
-#[repr(C)]
-#[derive(Default, Copy, Clone)]
-pub struct ShaderSystemO {
-    pub _address: u8,
-}
-#[repr(C)]
-#[derive(Default, Copy, Clone)]
-pub struct ShaderConstantBufferInstanceT {
-    pub _address: u8,
-}
-#[repr(C)]
-#[derive(Default, Copy, Clone)]
-pub struct ShaderResourceBinderInstanceT {
-    pub _address: u8,
-}
-#[repr(C)]
-#[derive(Default, Copy, Clone)]
-pub struct ShaderO {
-    pub _address: u8,
-}
 
 // Extensions generated by machinery-generator
 
@@ -1574,6 +1514,10 @@ use const_cstr::{const_cstr, ConstCStr};
 use crate::foundation::*;
 use crate::plugins::editor_views::*;
 use crate::plugins::entity::*;
+use crate::plugins::render_graph::*;
+use crate::plugins::renderer::*;
+use crate::plugins::shader_system::*;
+use crate::plugins::simulate::*;
 use crate::plugins::ui::*;
 
 impl AssetPreviewApi {
